netapp_ontap.models.error API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.error`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ErrorSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the Error object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `arguments GET`

    Message arguments

  `code GET`

    Error code

    Example: 4

  `message GET`

    Error message

    Example: entry doesn't exist

  `target GET`

    The target parameter that caused the error.

    Example: uuid